@@ -14,11 +14,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.003003
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003003';
+our $VERSION = '0.003004';
 
 # Dependencies
 use parent 'Exporter::Tiny';
@@ -56,17 +56,6 @@ use overload (
     # Copyright 2001, 2004 Foo (work address) <foo@zorg.org>
     # Copyright 2003 Foo B. and friends
 
-    print $copyright->normalize(
-      alias  => {
-        [ 'foo@bar.baz' => [ 'fb@acme.com', 'foo@zorg.org'] ] }
-      mangle => {
-        [ 's/Foo Barbaz\K(?= and .*)$/ <foo@bar.baz>/' ] }
-    );
-
-    # Copyright 1999-2000, 2002-2003 Acme Corp.
-    # Copyright 1999-2004 Foo Barbaz <foo@bar.baz>
-    # Copyright 2003 Foo B. and friends
-
 =head1 DESCRIPTION
 
 L<String::Copyright> Parses common styles of copyright statements
@@ -129,7 +118,7 @@ my $boilerplate_re
 # (?i)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)@\b[-_@]
 # (?im)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)[^ $]
 my $chatter_re
-	= qr/copyright$blank_or_break_re(?:(?:claim|eq|holder|info|information|law|notice|owner|ownership|statement|string)s?|and|in|is|on|to)(?:$|@\W|[^a-zA-Z0-9@_-])/im;
+	= qr/copyright$blank_or_break_re(?:(?:assigned|claim|eq|generated|holder|info|information|law|notice|owner|ownership|statement|string)s?|and|in|is|on|to)(?:$|@\W|[^a-zA-Z0-9@_-])/im;
 
 my $signs_re
 	= qr/(?:$sign_re|(?:^|$blank_re)$pseudo_sign_re)(?:$blank_re+(?:$sign_re|$pseudo_sign_re))*/m;
@@ -191,7 +180,10 @@ sub _generate_copyright
 
 			# normalize
 			if (@span) {
-				my $range = Number::Range->new( map {s/$dash_re/../r} @span );
+				## no critic (ProhibitMutatingListFunctions)
+				my $range
+					= Number::Range->new( map { s/$dash_re/../; $_ } @span );
+				## use critic
 				$years = $range->range;
 				$years =~ s/,/, /g;
 				$years =~ s/\.\./-/g;
@@ -238,15 +230,6 @@ sub new
 	bless [ undef, \@data ], __PACKAGE__;
 }
 
-sub normalize
-{
-	my ( $self, @opts ) = @_;
-	Carp::confess("normalize options not yet implemented")
-		if @opts;
-
-	new($self);
-}
-
 sub _compose
 {
 	my $format = $_[0]->[FORMAT];
